@@ -6,7 +6,7 @@ use warnings;
 
 use Perinci::Sub::PropertyUtil qw(declare_property);
 
-our $VERSION = '0.08'; # VERSION
+our $VERSION = '0.10'; # VERSION
 
 sub filter_using_for {
     my ($self, %args) = @_;
@@ -116,7 +116,7 @@ Perinci::Sub::Property::result_postfilter - (DEPRECATED) Postfilter function res
 
 =head1 VERSION
 
-version 0.08
+This document describes version 0.10 of Perinci::Sub::Property::result_postfilter (from Perl distribution Perinci-Sub-Property-result_postfilter), released on 2016-05-11.
 
 =head1 SYNOPSIS
 
@@ -178,17 +178,13 @@ But this currently can't convert coderefs. JSON also can't handle circular
 references, which neither this wrapper property nor the above way can work
 around.
 
-=head1 SEE ALSO
-
-L<Perinci>
-
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Perinci-Sub-Property-result_postfilter>.
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Perinci-Sub-Property-result_postfilter>.
+Source repository is at L<https://github.com/perlancar/perl-Perinci-Sub-Property-result_postfilter>.
 
 =head1 BUGS
 
@@ -198,13 +194,17 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
+=head1 SEE ALSO
+
+L<Perinci>
+
 =head1 AUTHOR
 
-Steven Haryanto <stevenharyanto@gmail.com>
+perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Steven Haryanto.
+This software is copyright (c) 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
